@@ -1051,7 +1051,9 @@ class Application(Frame):
         video_formats = DLUtils.format_filetype(avail_video_formats)
 
         #audio formats to download video
-        available_audio_formats = {audio_filetypes["mp3"]:None, audio_filetypes["m4a"]:None, "ogg":None, audio_filetypes["aac"]:None, audio_filetypes["wav"]:None, "don't care":None}
+        available_audio_formats = {audio_filetypes["mp3"]:None, audio_filetypes["m4a"]:None, "ogg":None, audio_filetypes["aac"]:None,
+                                   audio_filetypes["wav"]:None, audio_filetypes["opus"]: None, audio_filetypes["flac"]: None, "don't care":None}
+
         available_video_formats = {}
 
         for v in video_formats:
@@ -1441,8 +1443,18 @@ def search_videos(search_query: str, no_of_searches: int):
 
 
 # run_main(): Runs the main app
-def run_main(make_txt_setup: bool = True):
+def run_main(make_txt_setup: bool = False):
     if (root is not None):
+        global setting_data
+        global setting_file
+
+        #re-read the data from the setup file
+        if (make_txt_setup):
+            file_dir = os.getcwd()
+            setting_file = SetupFile("setup.txt", file_dir)
+
+        setting_data = setting_file.get_data()
+
         root.config(menu=menu_bar, bg="white")
 
         #start the word wrap
@@ -1468,11 +1480,10 @@ if (__name__ != "__main__"):
 
     #read the data from the setup file
     setting_file = SetupFile("setup.txt", file_dir)
-    setting_data = setting_file.get_data()
 
     #create the root window for the app
     root = Tk()
-    root.title("Youtube Downlader")
+    root.title("Youtube Downloader")
     sc_width = int(root.winfo_screenwidth() / 2)
     sc_height = int(root.winfo_screenheight() / 2)
     root.geometry(f"{sc_width}x{sc_height}+-7+0")
